import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class AppLocalizations {
  final Locale locale;

  AppLocalizations(this.locale);

  static AppLocalizations of(BuildContext context) =>
      Localizations.of<AppLocalizations>(context, AppLocalizations);

  Map<String, String> _localizedString;

  Future<void> load() async {
    String jsonFileName = 'assets/lang/${locale.languageCode}';
    if (locale.countryCode != null) {
      jsonFileName += '_${locale.countryCode}';
    }
    jsonFileName += '.json';

    String mainJsonString = await rootBundle.loadString('assets/lang/en.json');
    Map<String, dynamic> jsonMap = json.decode(mainJsonString);

    String localizedJsonString = await rootBundle.loadString(jsonFileName);
    jsonMap.addAll(json.decode(localizedJsonString));

    _localizedString =
        jsonMap.map((key, value) => MapEntry(key, value.toString()));
  }

  String translate(String key) => _localizedString[key];

  static const LocalizationsDelegate<AppLocalizations> delegate =
      _AppLocalizationsDelegate();
}

class _AppLocalizationsDelegate
    extends LocalizationsDelegate<AppLocalizations> {
  const _AppLocalizationsDelegate();

  @override
  bool isSupported(Locale locale) => true;

  @override
  Future<AppLocalizations> load(Locale locale) async {
    AppLocalizations localizations = new AppLocalizations(locale);
    await localizations.load();
    return localizations;
  }

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}
