// OpenLP Mobile Remote
// ---------------------------------------------------------------------------
// Copyright (c) 2008-2019 OpenLP Developers
// ---------------------------------------------------------------------------
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

import 'package:flutter/material.dart';

import '../configurations/app_localizations.dart';

class _Action {
  String titleKey;
  VoidCallback callback;
  _Action({@required this.titleKey, @required this.callback});
}

class DisplayOptionsDialog extends StatelessWidget {
  final List<_Action> _actions = [
    _Action(
      titleKey: 'display_option_blank',
      callback: () {
        print('Blank screen');
      },
    ),
    _Action(
      titleKey: 'display_option_theme',
      callback: () {
        print('Theme screen');
      },
    ),
    _Action(
      titleKey: 'display_option_desktop',
      callback: () {
        print('Desktop screen');
      },
    ),
    _Action(
      titleKey: 'display_option_show',
      callback: () {
        print('Show screen');
      },
    ),
  ];

  @override
  Widget build(BuildContext context) {
    return SimpleDialog(
      contentPadding: EdgeInsets.all(20.0),
      children: _actions
          .map((action) => OutlineButton(
                borderSide: BorderSide(color: Theme.of(context).primaryColor),
                textColor: Theme.of(context).primaryColor,
                child: Text(
                    AppLocalizations.of(context).translate(action.titleKey)),
                onPressed: () {
                  action.callback();
                  Navigator.of(context).pop();
                },
              ))
          .toList(),
    );
  }
}
