// OpenLP Mobile Remote
// ---------------------------------------------------------------------------
// Copyright (c) 2008-2019 OpenLP Developers
// ---------------------------------------------------------------------------
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

import 'package:flutter/material.dart';

import '../configurations/app_localizations.dart';
import '../resources/openlp_icons.dart';
import '../screens/search_service_item.dart';

class _ServiceItem {
  IconData icon;
  String titleKey;
  _ServiceItem({@required this.icon, @required this.titleKey});
}

class SelectServiceItemBottomSheet extends StatelessWidget {
  final List<_ServiceItem> _serviceItems = [
    _ServiceItem(icon: OpenLPIcons.songs, titleKey: 'plugin_songs_plural'),
    _ServiceItem(icon: OpenLPIcons.biblies, titleKey: 'plugin_bibles_plural'),
    _ServiceItem(icon: OpenLPIcons.presentations, titleKey: 'plugin_presentations_plural'),
    _ServiceItem(icon: OpenLPIcons.images, titleKey: 'plugin_images_plural'),
    _ServiceItem(icon: OpenLPIcons.media, titleKey: 'plugin_media_plural'),
    _ServiceItem(icon: OpenLPIcons.custom, titleKey: 'plugin_custom_plural'),
  ];
  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Wrap(
        children: _serviceItems.map((item) {
          return ListTile(
            dense: true,
            leading: Icon(item.icon),
            title: Text(AppLocalizations.of(context).translate(item.titleKey)),
            onTap: () {
              Navigator.of(context).pop();
              showSearch(context: context, delegate: SearchServiceItem());
            },
          );
        }).toList(),
      ),
    );
  }
}
